# Omniplate
A Python package for analysing data from plate-reader studies of growing biological cells. Users can correct for autofluorescence, determine growth rates and the amount of fluorescence per cell, and simultaneously analyse multiple experiments.

## Documentation
A tutorial is [available](https://swainlab.bio.ed.ac.uk/software/omniplate/).

## Development history
+ `v3.0`: Consistent use of snake_case, but breaking backwards compatibility

## Citation
Montaño-Gutierrez, L. F., Moreno, N. M., Farquhar, I. L., Huo, Y., Bandiera, L., & Swain, P. S. (2022). Analysing and meta-analysing time-series data of microbial growth and gene expression from plate readers. PLOS Computational Biology, 18(5), e1010138.
